import com.phidget22.*;

public class IRExample {

    public static final void main(String args[]) throws Exception {
        //Enable logging to stdout
        com.phidget22.Log.enable(LogLevel.INFO, null);
        
        IR ch = new IR();

        ch.addAttachListener(new AttachListener() {
			public void onAttach(AttachEvent ae) {
				IR phid = (IR) ae.getSource();
				try {
					if(phid.getDeviceClass() != DeviceClass.VINT){
						System.out.println("channel " + phid.getChannel() + " on device " + phid.getDeviceSerialNumber() + " attached");
					}
					else{
						System.out.println("channel " + phid.getChannel() + " on device " + phid.getDeviceSerialNumber() + " hub port " + phid.getHubPort() + " attached");
					}
				} catch (PhidgetException ex) {
					System.out.println(ex.getDescription());
				}
			}
        });

        ch.addDetachListener(new DetachListener() {
			public void onDetach(DetachEvent de) {
				IR phid = (IR)de.getSource();
				try {
					if (phid.getDeviceClass() != DeviceClass.VINT) {
						System.out.println("channel " + phid.getChannel() + " on device " + phid.getDeviceSerialNumber() + " detached");
					} else {
						System.out.println("channel " + phid.getChannel() + " on device " + phid.getDeviceSerialNumber() + " hub port " + phid.getHubPort() + " detached");
					}
				} catch (PhidgetException ex) {
					System.out.println(ex.getDescription());
				}
			}
        });

        ch.addErrorListener(new ErrorListener() {
			public void onError(ErrorEvent ee) {
				System.out.println("Error: " + ee.getDescription());
			}
        });

        ch.addCodeListener(new IRCodeListener() {
			public void onCode(IRCodeEvent e) {
				System.out.println("In Code Listener");
				System.out.println("Code Read: " + e.getCode());
				System.out.println("Bit Count: " + e.getBitCount());
				System.out.println("Repeat: " + e.getIsRepeat() + "\n");
			}
        });

        ch.addLearnListener(new IRLearnListener() {
			public void onLearn(IRLearnEvent le) {
				System.out.println("In Learn Handler");
				System.out.println("Code Read: 0x" + le.getCode() + "\n");
				String encodingString, lengthString;
				int toggleMaskBytes;

				switch (le.getCodeInfo().encoding) {
					case UNKNOWN:
						encodingString = "Unknown";
						break;
					case SPACE:
						encodingString = "Space";
						break;
					case PULSE:
						encodingString = "Pulse";
						break;
					case BI_PHASE:
						encodingString = "BiPhase";
						break;
					case RC5:
						encodingString = "RC5";
						break;
					case RC6:
						encodingString = "RC6";
						break;
					default:
						encodingString = "Unknown";
						break;
				}

				switch (le.getCodeInfo().length) {
					case UNKNOWN:
						lengthString = "Unknown";
						break;
					case CONSTANT:
						lengthString = "Constant";
						break;
					case VARIABLE:
						lengthString = "Variable";
						break;
					default:
						lengthString = "Unknown";
						break;
				}

				System.out.println("Learned Code Info");
				System.out.println("----------------------------------------------------");
				System.out.println("Bit Count: " + le.getCodeInfo().bitCount + "\nEncoding: " + encodingString + "\nLength: " + lengthString + "\nGap: " + le.getCodeInfo().gap + "\nTrail: " + le.getCodeInfo().trail);
				System.out.println("Header: { " + le.getCodeInfo().header[0] + "," + le.getCodeInfo().header[1] + " }\nZero: {" + le.getCodeInfo().one[0] + "," + le.getCodeInfo().one[1] + " }");
				System.out.print("Repeat: {");
				for (int i = 0; i < 26; i++) {
					if (le.getCodeInfo().repeat[i] == 0) {
						break;
					}
					if (i == 0) {
						System.out.print(le.getCodeInfo().repeat[i]);
					} else {
						System.out.print(" ," + le.getCodeInfo().repeat[i]);
					}
				}
				System.out.println("}\nMinRepeat: " + le.getCodeInfo().minRepeat);
				System.out.println("Toggle Mask: ");

				toggleMaskBytes = 0;
				if ((le.getCodeInfo().bitCount % 8) == 0) {
					toggleMaskBytes = (le.getCodeInfo().bitCount / 8) + 0;
				} else {
					toggleMaskBytes = (le.getCodeInfo().bitCount / 8) + 1;
				}

				for (int i = 0; i < toggleMaskBytes; i++) {
					System.out.println(le.getCodeInfo().toggleMask);
				}
				System.out.println("Carrier Frequency: " + le.getCodeInfo().carrierFrequency + "\nDuty Cycle: " + le.getCodeInfo().dutyCycle + "\n");
				System.out.println("----------------------------------------------------\n");
			}
		});

        try {
              /*
            * Please review the Phidget22 channel matching documentation for details on the device
            * and class architecture of Phidget22, and how channels are matched to device features.
            */

            /*
            * Specifies the serial number of the device to attach to.
            * For VINT devices, this is the hub serial number.
            *
            * The default is any device.
            */
            //ch.setDeviceSerialNumber(<YOUR DEVICE SERIAL NUMBER>);
            /*
            * For VINT devices, this specifies the port the VINT device must be plugged into.
            *
            * The default is any port.
            */
            //ch.setHubPort(0);

            /*
            * Specifies that the channel should only match a VINT hub port.
            * The only valid channel id is 0.
            *
            * The default is 0 (false), meaning VINT hub ports will never match
            */
             //ch.setIsHubPortDevice(true);

            /*
            * Specifies which channel to attach to.  It is important that the channel of
            * the device is the same class as the channel that is being opened.
            *
            * The default is any channel.
            */
            //ch.setChannel(0);

            /*
            * In order to attach to a network Phidget, the program must connect to a Phidget22 Network Server.
            * In a normal environment this can be done automatically by enabling server discovery, which
            * will cause the client to discovery and connect to available servers.
            *
            * To force the channel to only match a network Phidget, set remote to 1.
            */
            // Net.enableServerDiscovery(ServerType.DEVICE);
            // ch.setIsRemote(true);

            System.out.println("Opening and waiting 5 seconds for attachment...");
            ch.open(5000);
            
            System.out.println("\n\nGathering data for 10 seconds\n\n");
            Thread.sleep(10000);

            ch.close();
            System.out.println("\nClosed IR");
            
        } catch (PhidgetException ex) {
            System.out.println(ex.getDescription());
        }

    }
}
